export interface OSUserBasic {
  guid: string;
  faceUrl?: string;
  avatarUrl?: string;
  name: string;
  phoneNumber?: string;
  unconfirmedPhoneNumber?: string;
  phoneNumberVerified: boolean;
  email?: string;
  unconfirmedEmail?: string;
  emailVerified: boolean;
  accountType?: "oneId" | "localId" | "contact";
}
