export interface AccessEventDataSet {
  time: number;
  direction?: number;
  count: number;
}

export interface VisitDataSet {
  address: string;
  count: number;
}

export interface VisitDataSetPersonModal {

   name: string;
   count: number;
   
}
