type BoolNum = 0 | 1;

type GUID = string & { __brand: "uuid" };
type ULID = string & { __brand: "ulid" };
type Email = string & { __brand: "email" };
type PhoneNumber = string & { __brand: "tel" };
type UnixTimestamp = number & { __brand: "UnixTimestamp" };
type Timestamp = string & { __brand: "timestamp" };
type DateString = string & { __brand: "date" };
type Time = string & { __brand: "time" };
type IPv4 = string & { __brand: "IPv4" };
type IPv6 = string & { __brand: "IPv6" };
type UndecodedJson = string & { __brand: "UndecodedJson" };