export interface OSNoteProps {
  user: string;
  site: string;
}

export interface OSNoteForm {
  user: string;
  manager: string;
  site: string;
  content: string;
}

export interface OSNoteModel {
  guid: string;
  content: string;
  manager: string;
  timestamp: number;
}
