import React, { PropsWithChildren } from "react";

export interface CollapseProps
  extends PropsWithChildren,
    React.HTMLAttributes<HTMLDivElement> {
  collapsed: boolean;
  layout?: "vertical" | "horizontal"

  //Animation duration in seconds
  duration?: number;
}
