export const Log = (value: unknown) => console.log(value);
export const Warn = (value: unknown) => console.warn(value);
export const Error = (value: unknown) => console.error(value);
export const Table = (value: unknown) => console.table(value);
