import { HTMLAttributes, PropsWithChildren } from "react";
import { OSPanel } from "./OSPanel";

/**
 * Configuration for {@link OSPanel}
 */
export interface OSPanelProps
  extends PropsWithChildren,
    HTMLAttributes<HTMLDivElement> {}
