export enum BootstrapStyles {
  PRIMARY = "primary",
  SECONDARY = "secondary",
  SUCCESS = "success",
  DANGER = "danger",
  WARNING = "warning",
  INFO = "info",
  LIGHT = "light",
  DARK = "dark",
  LINK = "link",
  OUTLINE_PRIMARY = "outline-primary",
  OUTLINE_SECONDARY = "outline-secondary",
  OUTLINE_SUCCESS = "outline-success",
  OUTLINE_DANGER = "outline-danger",
  OUTLINE_WARNING = "outline-warning",
  OUTLINE_INFO = "outline-info",
  OUTLINE_LIGHT = "outline-light",
  OUTLINE_DARK = "outline-dark",
}

export enum PrimeStyles {
  SUCCESS = "succcess",
  INFO = "info",
  WARN = "warn",
  ERROR = "error",
  SECONDARY = "secondary",
  CONTRACT = "contrast",
}

export enum BootstrapButtonSizes {
  STANDARD = "",
  LARGE = "btn-lg",
  SMALL = "btn-sm",
}

export enum TableSize {
  SMALL = "small",
  NORMAL = "normal",
  LARGE = "large",
}

export enum TableFilterTypes {
  ROW = "row",
  MENU = "menu",
}
