export const isEmpty = (
  value: unknown,
  includeString: boolean = true,
): boolean => {
  if (includeString) {
    return value === "" || value === undefined || value === null;
  }
  return value === undefined || value === null;
};
