import { OSAvatarProps } from "../avatar";
import { OSLabelProps } from "../label";

/**
 * Standardized combination of OSAvatar and OSLabel.
 */
export interface OSInfoTileProps extends React.HTMLAttributes<HTMLElement> {
  avatar: Omit<OSAvatarProps, "size">;
  label: OSLabelProps;
}
