export interface Pet {
  name?: string;
  species: Species;
  colour?: string;
  gender: PetGender;
  image?: string;
  microChipped: boolean;
}

export enum Species {
  "Dog" = 1,
  "Cat" = 2,
  "Bird" = 3,
  "Rabbit" = 4,
  "Rodent" = 5,
  "Fish" = 6,
  "Lizard" = 7,
  "Snake" = 8,
  "Amphibian" = 9,
  "Reptile" = 10,
  "Other" = 11,
}

export enum PetGender {
  "Unknown" = 0,
  "Male" = 1,
  "Female" = 2,
}
