export interface Vehicle {
  name: string | null;
  id: string | number;
  vin: string;
  reg_id: string;
  current_user_id: string;
  make: string;
  model: string;
  colour: string;
  year: string;
  created_at: string;
  updated_at: string;
}
