import { EmbeddedLoading } from "../../types/props";
import { OSLabelProps } from "../label";
import { OSChip } from "./OSChip";

/**
 * Configuration options for {@link OSChip}.
 * 
 * Also contains `loading` state which toggles skeleton of same height.
 */
export interface OSChipProps extends 
EmbeddedLoading,
OSLabelProps {
  backgroundColour?: string | undefined;
  borderColour?: string | undefined;
}
